==> meme_generator-0.1.10-py3-none-any.whl: meme_generator/tags.py <==
class MemeTags:
    # 米家游戏
    mihoyo = {"米哈游"}

    genshin = {"原神"} | mihoyo
    star_rail = {"崩坏：星穹铁道"} | mihoyo
    honkai3 = {"崩坏3"} | mihoyo

    nahida = {"纳西妲", "草神"} | genshin
    hutao = {"胡桃"} | genshin
    klee = {"可莉"} | genshin
    keqing = {"刻晴"} | genshin
    zhongli = {"钟离"} | genshin
    nilou = {"妮露"} | genshin
    yae_miko = {"八重神子"} | genshin
    ayaka = {"神里绫华"} | genshin
    bronya = {"布洛妮娅·扎伊切克"} | honkai3
    captain = {"休伯利安号", "舰长"} | honkai3
    griseo = {"格蕾修"} | honkai3
    firefly = {"流萤"} | star_rail

    # 蔚蓝档案
    blue_archive = {"蔚蓝档案", "碧蓝档案"}

    shiroko = {"砂狼白子"} | blue_archive
    kokona = {"春原心奈", "春原心菜"} | blue_archive
    plana = {"普拉娜"} | blue_archive
    arona = {"阿罗娜"} | blue_archive

    # 公主连结
    re_dive = {"公主连结"}

    karyl = {"凯露"} | re_dive

    # 间谍过家家
    spy_family = {"间谍过家家"}

    anya = {"阿尼亚·福杰"} | spy_family

    # 孤独摇滚
    bocchi_the_rock = {"孤独摇滚"}

    bocchi = {"后藤独", "后藤一里", "波奇酱"} | bocchi_the_rock
    nijika = {"伊地知虹夏"} | bocchi_the_rock

    # 咒术回战
    jujutsu_kaisen = {"咒术回战"}

    sukuna = {"两面宿傩"} | jujutsu_kaisen

    # 葬送的芙莉莲
    sousou_no_frieren = {"葬送的芙莉莲"}

    frieren = {"芙莉莲"} | sousou_no_frieren

    # 我推的孩子
    oshi_no_ko = {"我推的孩子"}

    # LoveLive!Superstar!!
    lovelive_superstar = {"LoveLive!Superstar!!"}

    tan_kuku = {"唐可可"} | lovelive_superstar

    # 莉可丽丝
    lycoris_recoil = {"莉可丽丝"}

    takina = {"井之上泷奈"} | lycoris_recoil
    walnut = {"胡桃"} | lycoris_recoil

    # 别当欧尼酱了
    onimai = {"别当欧尼酱了"}

    mahiro = {"绪山真寻"} | onimai

    # 幸运星
    lucky_star = {"幸运星"}

    konata = {"泉此方"} | lucky_star

    # 凉宫春日
    haruhi = {"凉宫春日"}

    # 猫和老鼠
    tom_and_jerry = {"猫和老鼠"}

    tom = {"汤姆"} | tom_and_jerry
    jerry = {"杰瑞"} | tom_and_jerry

    # 瑞克和莫蒂
    rick_and_morty = {"瑞克和莫蒂"}

    rick = {"瑞克·桑切斯"} | rick_and_morty

    # VTuber
    gura = {"噶呜·古拉", "Gawr Gura", "鲨鲨"}

    # VOCALOID
    miku = {"初音未来"}

    # 明日方舟
    arknights = {"明日方舟"}

    # 东方Project
    touhou = {"东方Project"}

    # 舞萌
    maimai = {"舞萌"}

    # 学园偶像大师
    gakuen_imas = {"学园偶像大师"}

    kotone = {"藤田琴音"} | gakuen_imas

    # 哈利·波特
    harry_potter = {"哈利·波特"}

    # 鸣潮
    wuthering_waves = {"鸣潮"}

    jinhsi = {"今汐"} | wuthering_waves

    #世界计划
    project_sekai = {"世界计划"}

    # 其他
    capoo = {"猫猫虫", "咖波"}
    nekoha = {"猫羽雫"}
    kirby = {"星之卡比"}
    atri = {"亚托莉", "ATRI", "萝卜子"}

==> meme_generator-0.1.11-py3-none-any.whl: meme_generator/tags.py <==
class MemeTags:
    # 米家游戏
    mihoyo = {"米哈游"}

    genshin = {"原神"} | mihoyo
    star_rail = {"崩坏：星穹铁道"} | mihoyo
    honkai3 = {"崩坏3"} | mihoyo

    nahida = {"纳西妲", "草神"} | genshin
    hutao = {"胡桃"} | genshin
    klee = {"可莉"} | genshin
    keqing = {"刻晴"} | genshin
    zhongli = {"钟离"} | genshin
    nilou = {"妮露"} | genshin
    yae_miko = {"八重神子"} | genshin
    ayaka = {"神里绫华"} | genshin
    bronya = {"布洛妮娅·扎伊切克"} | honkai3
    captain = {"休伯利安号", "舰长"} | honkai3
    griseo = {"格蕾修"} | honkai3
    firefly = {"流萤"} | star_rail

    # 蔚蓝档案
    blue_archive = {"蔚蓝档案", "碧蓝档案"}

    arisu = {"天童爱丽丝"} | blue_archive
    izuna = {"久田泉奈","忍忍"} | blue_archive
    key = {"key"} | blue_archive
    kokona = {"春原心奈","春原心菜"} | blue_archive
    mari = {"伊落玛丽"} | blue_archive
    sena = {"冰室濑名"} | blue_archive
    shiroko = {"砂狼白子"} | blue_archive
    yuuka = {"早濑优香","邮箱"} | blue_archive

    arona = {"阿罗娜"} | blue_archive
    plana = {"普拉娜"} | blue_archive

    # 公主连结
    re_dive = {"公主连结"}

    karyl = {"凯露"} | re_dive

    # 间谍过家家
    spy_family = {"间谍过家家"}

    anya = {"阿尼亚·福杰"} | spy_family

    # 孤独摇滚
    bocchi_the_rock = {"孤独摇滚"}

    bocchi = {"后藤独", "后藤一里", "波奇酱"} | bocchi_the_rock
    nijika = {"伊地知虹夏"} | bocchi_the_rock

    # 咒术回战
    jujutsu_kaisen = {"咒术回战"}

    sukuna = {"两面宿傩"} | jujutsu_kaisen

    # 葬送的芙莉莲
    sousou_no_frieren = {"葬送的芙莉莲"}

    frieren = {"芙莉莲"} | sousou_no_frieren

    # 我推的孩子
    oshi_no_ko = {"我推的孩子"}

    # LoveLive!Superstar!!
    lovelive_superstar = {"LoveLive!Superstar!!"}

    tan_kuku = {"唐可可"} | lovelive_superstar

    # 莉可丽丝
    lycoris_recoil = {"莉可丽丝"}

    takina = {"井之上泷奈"} | lycoris_recoil
    walnut = {"胡桃"} | lycoris_recoil

    # 别当欧尼酱了
    onimai = {"别当欧尼酱了"}

    mahiro = {"绪山真寻"} | onimai

    # 幸运星
    lucky_star = {"幸运星"}

    konata = {"泉此方"} | lucky_star

    # 凉宫春日
    haruhi = {"凉宫春日"}

    # 猫和老鼠
    tom_and_jerry = {"猫和老鼠"}

    tom = {"汤姆"} | tom_and_jerry
    jerry = {"杰瑞"} | tom_and_jerry

    # 瑞克和莫蒂
    rick_and_morty = {"瑞克和莫蒂"}

    rick = {"瑞克·桑切斯"} | rick_and_morty

    # VTuber
    gura = {"噶呜·古拉", "Gawr Gura", "鲨鲨"}

    # VOCALOID
    miku = {"初音未来"}
    luotianyi = {"洛天依"}

    # 明日方舟
    arknights = {"明日方舟"}

    # 东方Project
    touhou = {"东方Project"}

    # 舞萌
    maimai = {"舞萌"}

    # 学园偶像大师
    gakuen_imas = {"学园偶像大师"}

    kotone = {"藤田琴音"} | gakuen_imas

    # 哈利·波特
    harry_potter = {"哈利·波特"}

    # 鸣潮
    wuthering_waves = {"鸣潮"}

    jinhsi = {"今汐"} | wuthering_waves

    # 世界计划
    project_sekai = {"世界计划"}

    # 其他
    capoo = {"猫猫虫", "咖波"}
    nekoha = {"猫羽雫"}
    kirby = {"星之卡比"}
    atri = {"亚托莉", "ATRI", "萝卜子"}
